# Getting Started

Get up and running with `mitre-emb3d` in minutes.

- **[Installation](installation.md)** — Install the tool via `uvx`, `uv`, or `pip`
- **[Quick Start](quickstart.md)** — Run your first commands and explore the EMB3D framework
